Models specified by growthSS or mvSS are represented by a pcvrss object,
which contains the model type, formulas, starting values or priors, the data for the model
to use, and the model backend to use.
Slots
formulaThe formula that will be used to fit the model.
priorPriors if the model is a Bayesian model (ie using the brms backend).
initfunInitialization function if the model is a Bayesian model.
dfThe data that will be used to fit the model.
familyThe model family, currently only used in the brms backend.
pcvrFormThe formula that was specified in growthSS and used in other pcvr functions.
typeThe model backend.
modelThe name of the main growth formula.
callstartStarting values for frequentist models.
tausQuantiles for nlrq/rq models.